@@ -1,7 +1,7 @@
 #' @importFrom Rdpack reprompt
 
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("Parallel numerical derivatives v. 0.0.7 (2025-03-01).")
+  packageStartupMessage("Parallel numerical derivatives v.0.0.8 (2025-03-04).")
 
   # The number of cores is auto-detected based on the OS
   os <- Sys.info()[["sysname"]]
@@ -9,10 +9,10 @@
     cores <- sum(!duplicated(grep("^core id", readLines("/proc/cpuinfo"), value = TRUE)))
   } else if (os == "Darwin") {
     # Accepting only unambiguous values
-    cores <- tryCatch(as.integer(system("sysctl -n hw.physicalcpu", TRUE)),
+    cores <- tryCatch(as.integer(system("/usr/sbin/sysctl -n hw.physicalcpu", TRUE)),
                       warning = function(e) return(NULL),
                       error = function(e) return(NULL))
-  } else {  # Unfortunately one cannot go to system files
+  } else {  # Unfortunately one cannot dig inside system files
     cores <- parallel::detectCores(logical = FALSE)
   }
   # Worst case: less than a quarter is returned
@@ -28,7 +28,11 @@
   }
   packageStartupMessage(msg)
 
+  max.cores <- parallel::detectCores()  # Max. useful # of cores assuming availability
+
+  # Providing global options for faster invocation later
   options(pnd.cores = getOption("pnd.cores", cores))
+  options(pnd.max.cores = getOption("pnd.max.cores", max.cores))
   options(pnd.preschedule = getOption("pnd.preschedule", TRUE))
   options(pnd.warn.vectorised = getOption("pnd.warn.vectorised", FALSE))
 }
